  function [tnew,Fnew,Jnew] = NStep(FName,JName,tc,Fc,Jc,plist)
%
% Pre:
%     FName     the name of a function F(t,plist) that accepts  a column
%               n-vector and returns a column n-vector
%     JName     the name of a function JF(t,plist) that returns the
%               Jacobian of F at t.
%        tc     a column n-vector, an approximate zero.         
%        Fc     F(tc,plist)
%        Jc     JF(tc,plist), assumed nonsingular
%     plist     parameter list
%
% Post:
%      tnew     a column n-vector, an improved approximate obtained
%               by a single Newton iteration.
%      Fnew     F(tnew,plist) 
%      Jnew     JF(tnew,plist)
%
       sc = -(Jc\Fc);
	   tnew = tc + sc;
	   Fnew = feval(FName,tnew,plist);
	   Jnew = feval(JName,tnew,plist);
