% Script File: ShowKepler
%
% Applies ODE23 and ODE45 to a system of differential equations
% that define an elliptical orbit.

 
  close all
  
  tInitial = 0;
  tFinal   =  2*pi;
  tol = .0001;
  uInitial = [ .4; 0 ; 0 ; 2];
  trace = 0;
  
  [t, u] = ODE23('Kepler', tInitial, tFinal, uInitial, tol,trace);
  
  figure
  plot(u(:,1),u(:,3))
  axis('square','equal')
  title(sprintf('ODE23 Steps = %5.0f, tol = %5.0e',length(t),tol))
  

  [t, u] = ODE45('Kepler', tInitial, tFinal, uInitial, tol,trace);
  
  
  figure
  plot(u(:,1),u(:,3))
  axis('square','equal')
  title(sprintf('ODE23 Steps = %5.0f, tol = %5.0e',length(t),tol))
    
  tvals = linspace(tInitial,tFinal);
  xvals = spline(t,u(:,1),tvals);
  yvals = spline(t,u(:,3),tvals);
  figure
  plot(xvals,yvals)
  axis('square','equal')
  title(sprintf('ODE45 Steps = %5.0f, tol = %5.0e',length(t),tol))
  xlabel('(With Spline Smoothing)')

